__title__ = "vk-bot"
__version__ = "0.1.5"
__description__ = "Python 2/3 VK bot builder."
__url__ = "https://github.com/Suenweek/vk-bot"
__author__ = "Roman Novatorov"
__author_email__ = "roman.novatorov@gmail.com"
